@@ -21,7 +21,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
@@ -114,7 +114,7 @@ class Arch : public QObject
     void unarchFile( QStringList *, const QString & _destDir,
                              bool viewFriendly = false );
 
-    QString fileName() const { return m_filename; };
+    QString fileName() const { return m_filename; }
 
     enum EditProperties{ Add = 1, Delete = 2, Extract = 4,
                          View = 8, Integrity = 16 };
@@ -130,11 +130,19 @@ class Arch : public QObject
     void verifyUtilityIsAvailable( const QString &,
                                    const QString & = QString::null );
 
-    bool utilityIsAvailable() { return m_bUtilityIsAvailable; }
+    void verifyCompressUtilityIsAvailable( const QString &utility );
 
-    QString getUtility() { return m_archiver_program; }
+    void verifyUncompressUtilityIsAvailable( const QString &utility );
 
-    void appendShellOutputData( const char * data ) { m_lastShellOutput.append( data ); }
+    bool archUtilityIsAvailable() { return m_bArchUtilityIsAvailable; }
+
+    bool unarchUtilityIsAvailable() { return m_bUnarchUtilityIsAvailable; }
+
+    QString getArchUtility() { return m_archiver_program; }
+
+    QString getUnarchUtility() { return m_unarchiver_program; }
+
+    void appendShellOutputData( const char * data ) { m_lastShellOutput.append( QString::fromLocal8Bit( data ) ); }
     void clearShellOutput() { m_lastShellOutput.truncate( 0 ); }
     const QString& getLastShellOutput() const { return m_lastShellOutput; }
 
@@ -172,8 +180,11 @@ class Arch : public QObject
     // lets tar delete unsuccessfully before adding without confusing the user
     bool m_bNotifyWhenDeleteFails;
 
-    // set to whether the archiving utility/utilities is/are in the user's PATH
-    bool m_bUtilityIsAvailable;
+    // set to whether if the compressing utility is in the user's PATH
+    bool m_bArchUtilityIsAvailable;
+
+    // set to whether if the uncompressing utility is in the user's PATH
+    bool m_bUnarchUtilityIsAvailable;
 
     QString m_archiver_program;
     QString m_unarchiver_program;
@@ -201,7 +212,7 @@ class Arch : public QObject
 #define LINK_COLUMN        qMakePair( i18n(" Link "),        Qt::AlignLeft  )
 #define PACKED_COLUMN      qMakePair( i18n(" Size Now "),    Qt::AlignRight )
 #define RATIO_COLUMN       qMakePair( i18n(" Ratio "),       Qt::AlignRight )
-#define CRC_COLUMN         qMakePair( i18n("Cyclic Redundancy Check"," CRC "), Qt::AlignRight )
+#define CRC_COLUMN         qMakePair( i18n("Cyclic Redundancy Check"," CRC "), Qt::AlignLeft )
 #define METHOD_COLUMN      qMakePair( i18n(" Method "),  Qt::AlignLeft  )
 #define VERSION_COLUMN     qMakePair( i18n(" Version "), Qt::AlignLeft  )
 #define OWNER_COLUMN       qMakePair( i18n(" Owner "),   Qt::AlignLeft  )
