@@ -82,7 +82,7 @@ bool RarArch::processLine( const QCString &line )
 {
   if ( m_isFirstLine )
   {
-    m_entryFilename = line;
+    m_entryFilename = QString::fromLocal8Bit( line );
     m_entryFilename.remove( 0, 1 );
     m_isFirstLine = false;
     return true;
@@ -98,7 +98,7 @@ bool RarArch::processLine( const QCString &line )
   list << l2[ 2 ]; // ratio
 
   QStringList date =  QStringList::split( '-', l2[ 3 ] );
-  list << ArkUtils::fixYear( date[ 2 ].latin1() ) + "-" + date[ 1 ] + "-" + date [ 0 ] + " " + l2[4]; // date
+  list << ArkUtils::fixYear( date[ 2 ].latin1() ) + '-' + date[ 1 ] + '-' + date [ 0 ] + ' ' + l2[4]; // date
   list << l2[ 5 ]; // attributes
   list << l2[ 6 ]; // crc
   list << l2[ 7 ]; // method
@@ -226,6 +226,8 @@ void RarArch::unarchFileInternal()
 
   if ( !m_password.isEmpty() )
     *kp << "-p" + m_password;
+  else
+    *kp << "-p-";
 
   if ( !ArkSettings::extractOverwrite() )
   {
