@@ -6,19 +6,15 @@
 
 #include "kcharselectdia.h"
 
-#include <kapp.h>
-#include <qstring.h>
+#include <kapplication.h>
 #include <kconfig.h>
-#include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
+#include <kglobalsettings.h>
 
-static const char *description = 
+static const char description[] = 
 	I18N_NOOP("KDE character selection utility");
 
-static const char *version = "v0.0.1";
-
-
 /*================================================================*/
 int main(int argc, char **argv)
 {
@@ -26,18 +22,24 @@ int main(int argc, char **argv)
     version, description, KAboutData::License_GPL,
     "(c) 1999, Reginald Stadlbauer");
   aboutData.addAuthor("Reginald Stadlbauer",0, "reggie@kde.org");
-  KCmdLineArgs::init( argc, argv, &aboutData );
+  aboutData.addCredit( "Nadeem Hasan", I18N_NOOP( "GUI cleanup and fixes" ),
+        "nhasan@kde.org" );
+  aboutData.addCredit( "Ryan Cumming", I18N_NOOP( "GUI cleanup and fixes" ),
+        "bodnar42@phalynx.dhs.org" );
+  aboutData.addCredit("Benjamin C. Meyer",I18N_NOOP("XMLUI conversion"),"ben+kcharselect@meyerhome.net");
+	KCmdLineArgs::init( argc, argv, &aboutData );
 
   KApplication app;
 
   KConfig *config = kapp->config();
 
   config->setGroup("General");
-  QString font(config->readEntry("font","times"));
+  QString font(config->readEntry("selectedFont", KGlobalSettings::generalFont().family()));
   QChar c = QChar(static_cast<unsigned short>(config->readNumEntry("char",33)));
   int tn = config->readNumEntry("table",0);
+  bool direction = config->readNumEntry("entryDirection",0);
   
-  KCharSelectDia *dia = new KCharSelectDia(0L,"",c,font,tn);
+  KCharSelectDia *dia = new KCharSelectDia(0L,"",c,font,tn,direction);
 
   app.setMainWidget(dia);
   dia->show();
