@@ -82,7 +82,7 @@ keyServer::keyServer(QWidget *parent, const char *name,bool modal,bool autoClose
         }
 
 
-        KProcIO *encid=new KProcIO();
+        KProcIO *encid=new KProcIO(QTextCodec::codecForLocale());
         *encid << "gpg"<<"--no-secmem-warning"<<"--no-tty"<<"--with-colon"<<"--list-keys";
         QObject::connect(encid, SIGNAL(readReady(KProcIO *)),this, SLOT(slotprocread(KProcIO *)));
         encid->start(KProcess::NotifyOnExit,true);
@@ -142,7 +142,7 @@ void keyServer::slotprocread(KProcIO *p)
                                 dead=false;
                                 break;
                         }
-                        tst=KgpgInterface::checkForUtf8(tst.section(':',9,9));
+                        tst=tst.section(':',9,9);
                         if (tst.length()>35) {
                                 tst.remove(35,tst.length());
                                 tst+="...";
@@ -185,15 +185,15 @@ void keyServer::slotSearch()
         count=0;
         cycle=false;
         readmessage=QString::null;
-        searchproc=new KProcIO();
+        searchproc=new KProcIO(QTextCodec::codecForLocale());
         QString keyserv=page->kCBimportks->currentText();
-        *searchproc<<"gpg";
+        *searchproc<<"gpg"<<"--utf8-strings";
         if (page->cBproxyI->isChecked()) {
                 searchproc->setEnvironment("http_proxy",page->kLEproxyI->text());
                 *searchproc<<	"--keyserver-options"<<"honor-http-proxy";
         } else
                 *searchproc<<	"--keyserver-options"<<"no-honor-http-proxy";
-        *searchproc<<"--keyserver"<<keyserv<<"--command-fd=0"<<"--status-fd=2"<<"--search-keys"<<page->kLEimportid->text().stripWhiteSpace().local8Bit();
+        *searchproc<<"--keyserver"<<keyserv<<"--command-fd=0"<<"--status-fd=2"<<"--search-keys"<<page->kLEimportid->text().stripWhiteSpace();
 
         keyNumbers=0;
         QObject::connect(searchproc, SIGNAL(processExited(KProcess *)),this, SLOT(slotsearchresult(KProcess *)));
@@ -314,16 +314,15 @@ void keyServer::slotsearchread(KProcIO *p)
                         QString subkey=required.stripWhiteSpace();
 			if (subkey.find(" key ")!=-1 && subkey.at(0).isDigit ())
 			{
-                        QString kid=subkey.section(" key ",1,1);
-                        kid=kid.stripWhiteSpace();
-                        kid=kid.left(8);
+                        QString kid=subkey.section(",",0,0).stripWhiteSpace();
+                        kid=kid.right(8);
 			kitem->setText(3,kid);
 			QString creation=subkey.section("created",1,1);
 			if (creation.startsWith(":")) creation=creation.right(creation.length()-1);
 			kitem->setText(2,creation);
 			cycle=false;
 			}
-			else 
+			else
 			{
 			if (subkey.find("<")!=-1) {
 	                keymail=subkey.section('<',-1,-1);
@@ -343,18 +342,18 @@ void keyServer::slotsearchread(KProcIO *p)
 
 void keyServer::slotPreExport()
 {
-slotExport(page->kCBexportkey->currentText().section(':',0,0));
+	slotExport(QStringList(page->kCBexportkey->currentText().section(':', 0, 0)));
 }
 
-void keyServer::slotExport(QString keyId)
+void keyServer::slotExport(QStringList keyIds)
 {
         if (page->kCBexportks->currentText().isEmpty())
                 return;
         readmessage=QString::null;
-        exportproc=new KProcIO();
+        exportproc=new KProcIO(QTextCodec::codecForLocale());
         QString keyserv=page->kCBexportks->currentText();
 
-        *exportproc<<"gpg";
+        *exportproc<<"gpg"<<"--utf8-strings";
 	if (!page->exportAttributes->isChecked())
                 *exportproc<<"--export-options"<<"no-include-attributes";
 
@@ -363,7 +362,7 @@ void keyServer::slotExport(QString keyId)
                 *exportproc<<	"--keyserver-options"<<"honor-http-proxy";
         } else
                 *exportproc<<	"--keyserver-options"<<"no-honor-http-proxy";
-        *exportproc<<"--status-fd=2"<<"--keyserver"<<keyserv<<"--send-keys"<<keyId;
+        *exportproc << "--status-fd=2" << "--keyserver" << keyserv << "--send-keys" << keyIds;
 
         QObject::connect(exportproc, SIGNAL(processExited(KProcess *)),this, SLOT(slotexportresult(KProcess *)));
         QObject::connect(exportproc, SIGNAL(readReady(KProcIO *)),this, SLOT(slotimportread(KProcIO *)));
@@ -411,10 +410,10 @@ void keyServer::slotImport()
                 return;
         }
         readmessage=QString::null;
-        importproc=new KProcIO();
+        importproc=new KProcIO(QTextCodec::codecForLocale());
         QString keyserv=page->kCBimportks->currentText();
-	
-        *importproc<<"gpg";
+
+        *importproc<<"gpg"<<"--utf8-strings";
         if (page->cBproxyI->isChecked()) {
                 importproc->setEnvironment("http_proxy",page->kLEproxyI->text());
                 *importproc<<	"--keyserver-options"<<"honor-http-proxy";
@@ -552,17 +551,18 @@ void keyServer::syncCombobox()
 
         QString optionsServer=KgpgInterface::getGpgSetting("keyserver", KGpgSettings::gpgConfigPath());
 
-	//if (optionsServer.isEmpty())
-	//	optionsServer="hkp://wwwkeys.pgp.net";
 	page->kCBexportks->clear();
 	page->kCBimportks->clear();
 
-	page->kCBexportks->insertItem(optionsServer);
-        page->kCBimportks->insertItem(optionsServer);
-
+	if (!optionsServer.isEmpty()) {
+		page->kCBexportks->insertItem(optionsServer);
+		page->kCBimportks->insertItem(optionsServer);
+	}
+	else if ( serverList.isEmpty() )
+		serverList = "hkp://wwwkeys.eu.pgp.net,hkp://search.keyserver.net,hkp://wwwkeys.pgp.net,hkp://pgp.dtype.org,hkp://wwwkeys.us.pgp.net"; // same as ini kgpgoptions.cpp
+	
 	page->kCBexportks->insertStringList(QStringList::split(",",serverList));
 	page->kCBimportks->insertStringList(QStringList::split(",",serverList));
-
 }
 
 void keyServer::slotOk()
