@@ -6,7 +6,7 @@
  *
  * This file contains the implementation of the main laptop battery monitoring daemon
  *
- * $Id: laptop_daemon.h 212185 2003-03-07 22:11:39Z waba $
+ * $Id: laptop_daemon.h 663513 2007-05-11 14:25:29Z lunakl $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "daemon_state.h"
@@ -110,6 +110,7 @@ private:
 	void 	invokeLogout();
 	void	displayPixmap();
 	void	setBlankSaver(bool);
+        void setLoadAverage(bool enable, float value) {mLavEnabled=enable&&(value>=0.0); mLav=value;}
 
 	laptop_dock *dock_widget;
 
@@ -159,6 +160,8 @@ protected:
 
 	//
 	XAutoLock	autoLock;		// timer/UI maint
+        float   mLav;
+        bool    mLavEnabled;
 	bool	need_wait;			// undo sleep stuff
 	bool	saved_brightness, saved_throttle, saved_performance;
 	int	saved_brightness_val;
