@@ -1,7 +1,7 @@
 /*
  * portable.cpp
  *
- * $Id: portable.cpp,v 1.93 2005/02/14 16:53:47 waba Exp $
+ * $Id: portable.cpp 770642 2008-02-04 09:40:51Z woebbe $
  *
  * Copyright (c) 1999 Paul Campbell <paul@taniwha.com>
  *
@@ -20,7 +20,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 //
@@ -138,17 +138,15 @@ apm_read(apm_info *ap)
 	   	&ap->battery_percentage,
 	   	&ap->battery_time,
 	   	tmp2);
-	if (s < 9)
+        fclose(f);
+	if (s < 9) 
 		return(1);	
-	if (version[0] == 'B') {
-		fclose(f);
+	if (version[0] == 'B')
 		return(2);
-	}
    	if (ap->battery_percentage > 100) 
 		ap->battery_percentage = -1;
 	if (strcmp(tmp2, "sec") == 0)
 		ap->battery_time /= 60;
-   	fclose(f);
 	return(0);
 }
 
@@ -578,7 +576,8 @@ has_software_suspend(int type)
 		known = last_seed;
 		available = 0;
 		present = (((::access("/proc/sys/kernel/swsusp", F_OK) == 0) ||
-                            (::access("/proc/software_suspend", F_OK) == 0)) &&
+                            (::access("/proc/software_suspend", F_OK) == 0) ||
+                            (::access("/proc/suspend2", F_OK) == 0)) &&
 		           ::access("/usr/sbin/hibernate", F_OK) == 0);
 		if (present) {
 			if (::getuid() == 0) {	// running as root
@@ -689,10 +688,31 @@ has_acpi_sleep(int state)
 	if (known != last_seed) {
 		known = last_seed;
 		mask = 0;
+
+		QFile p("/sys/power/state");
 		QFile f("/proc/acpi/sleep");
-		if (f.open(IO_ReadOnly)) {
+
+		if (p.open(IO_ReadOnly)) {
 			QString l;
-	       		f.readLine(l, 500);
+			QTextStream t(&p);
+			l = t.readLine();
+			QStringList ll = QStringList::split(' ',l,false);
+			for (QValueListIterator<QString> i = ll.begin(); i!=ll.end(); i++) {
+				QString s = *i;
+				
+				if (s.compare("standby")==0)
+				mask |= (1<<1);
+				else if (s.compare("mem")==0)
+				mask |= (1<<3);
+				else if (s.compare("disk")==0)
+				mask |= (1<<4);
+			}
+			p.close();
+		}
+		else if (f.open(IO_ReadOnly)) {
+			QString l;
+			QTextStream t(&f);
+			l = t.readLine();
 			QStringList ll = QStringList::split(' ',l,false);
 			for (QValueListIterator<QString> i = ll.begin(); i!=ll.end(); i++) {
 				QString s = *i;
@@ -1363,7 +1383,9 @@ acpi_sleep_access_ok()
 	if (known != last_seed) {
 		known = last_seed;
 	    	known_res = (::access("/proc/acpi/sleep", R_OK|W_OK)==0 && ::acpi_helper_ok(1)) ||
- 	                    (::access("/proc/acpi/sleep", R_OK)==0 && ::acpi_helper_ok(0));
+ 	                    (::access("/proc/acpi/sleep", R_OK)==0 && ::acpi_helper_ok(0)) ||
+	    	            (::access("/sys/power/state", R_OK|W_OK)==0 && ::acpi_helper_ok(1)) ||
+ 	                    (::access("/sys/power/state", R_OK)==0 && ::acpi_helper_ok(0));
 	}
 	return(known_res);
 }
@@ -1937,19 +1959,19 @@ bool
 laptop_portable::get_button(LaptopButton l)	// true if a button is pressed
 {
 	if (::has_acpi()) {
-		QString *name=0;
+		QString name;
 		switch (l) {
 		case LidButton:
-			name = &acpi_lid_name;
+			name = acpi_lid_name;
 			break;
 		case PowerButton:
-			name = &acpi_power_name;
+			name = acpi_power_name;
 			break;
 		default:
 			break;
 		}
-		if (name) {
-			QFile f(*name);
+		if (!name.isEmpty()) {
+			QFile f(name);
 			if (f.open(IO_ReadOnly)) {
 				while (!f.atEnd()) {
 					QString l;
@@ -2152,7 +2174,7 @@ KActiveLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
 //
 QLabel *laptop_portable::how_to_do_suspend_resume(QWidget *parent)
 {
- 	QLabel* note = new QLabel(i18n(" "), parent);
+ 	QLabel* note = new QLabel(" ", parent);
 	return(note);
 }
 
@@ -2558,7 +2580,7 @@ KActiveLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
 QLabel *laptop_portable::how_to_do_suspend_resume(QWidget *parent)
 {
 	// INSERT HERE
-       QLabel* note = new QLabel(i18n(" "), parent);
+       QLabel* note = new QLabel(" ", parent);
        return(note);
 }
 
@@ -2851,7 +2873,7 @@ KActiveLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
 //
 QLabel *laptop_portable::how_to_do_suspend_resume(QWidget *parent)
 {
- 	QLabel* note = new QLabel(i18n(" "), parent);
+ 	QLabel* note = new QLabel(" ", parent);
 	// INSERT HERE
 	return(note);
 }
